// ----------------------------------------------------------------------------
//
// frmRahmen(FishRahm.PAS/DFM)                            Ulrich Mller 14.1.00
//                                                        Procida 400NT Delphi4
// Testrahmen fr die KlassenUnit FishFaD4.DCU
// START macht OpenInterface, Anzeige Eigenschaften und Freigabe pnlTests
// InterfacePanel : Anzeige des internen Panels
// SetMotor : Test der Methoden SetMotor ... und anderer einfacher,
// SetLamp  : Test der Methoden SetLamp, EmergencyStop, ResetMotors
// WaitFor  : Test der WaitFor... Methoden  und Ereignisse.
// MoveTo   : Test MoveTo/Delta und OnPositionChange
//
// Ergebnisse und Dialogfhrung in lstLog (printLog)
//
// ----------------------------------------------------------------------------

unit FishRahm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, FishFaD4, ExtCtrls;

type
  TfrmRahmen = class(TForm)
    cmdStart: TButton;
    cmdEnde: TButton;
    lstLog: TListBox;
    pnlTests: TPanel;
    cmdMoveTo: TButton;
    cmdWaitFor: TButton;
    cmdAction: TButton;
    cmdPanel: TButton;
    cmdLampen: TButton;
    procedure cmdEndeClick(Sender: TObject);
    procedure cmdStartClick(Sender: TObject);
    procedure cmdPanelClick(Sender: TObject);
    procedure cmdActionClick(Sender: TObject);
    procedure cmdLampenClick(Sender: TObject);
    procedure cmdWaitForClick(Sender: TObject);
    procedure cmdMoveToClick(Sender: TObject);
    procedure OnInputImpuls(Sender: TFishFace; InputNr, ImpulsNr: LongInt);
    procedure OnInterfaceStatus(Sender: TFishFace; Status: LongInt);
    procedure OnPositionChange(Sender: TFishFace);
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    procedure printLog(Text: string); overload;
    procedure printLog(Funktion, StringWert: string); overload;
    procedure printLog(Funktion: string; IntegerWert: Integer); overload;
    procedure printLog(Funktion: string; BoolWert: Boolean); overload;
    procedure printLog(Funktion: string; HexWert, Lae: Cardinal); overload;
  public
    { Public-Deklarationen}
  end;

var
  frmRahmen: TfrmRahmen;

implementation

{$R *.DFM}

var
  PortName: string = 'COM1';
  ft: TFishFace;
  Mot1Pos: Integer;

// --- Log-Routinen (overload) ----------------------------------

procedure TfrmRahmen.printLog(Text: string);
begin
  lstLog.Items.Add(Text);
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmRahmen.printLog(Funktion, StringWert: string);
begin
  lstLog.Items.Add(Funktion + ' : ' + StringWert);
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmRahmen.printLog(Funktion: string; IntegerWert: Integer);
begin
  lstLog.Items.Add(Funktion + ' : ' + IntToStr(IntegerWert));
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmRahmen.printLog(Funktion: string; BoolWert: Boolean);
begin
  if BoolWert then lstLog.Items.Add(Funktion + ' : ' + 'true')
  else lstLog.Items.Add(Funktion + ' : ' + 'false');
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmRahmen.printLog(Funktion: string; HexWert, Lae: Cardinal);
begin lstLog.Items.Add(Funktion + ' : ' + IntToHex(HexWert, Lae) + 'h'); end;

// ----------------- Form-Routinen ---------------------------------------

procedure TfrmRahmen.FormCreate(Sender: TObject);
begin
  ft := TFishFace.Create;
  ft.LPTDelay   := 5;
  ft.LPTAnalog := 10;
end;

procedure TfrmRahmen.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  ft.NotHalt := true;
  ft.ClearMotors;
  ft.CloseInterface;
  ft.Free;
end;

procedure TfrmRahmen.cmdEndeClick(Sender: TObject);
// --- Beenden ------------------------------------------------------------
begin
  Self.Close;
end;

procedure TfrmRahmen.cmdStartClick(Sender: TObject);
// --- OpenInterface -------------------------------
//     Anzeige der aktuellen Eigenschaften ---------
var
  res: LongWord;
begin
if cmdStart.Caption = 'START' then begin
  if ParamCount = 0 then
    PortName := InputBox('umFishTest',
      'Bitte Portnamen eingeben : COM1-4 oder LPT1-3 (NT : LPT)', PortName)
  else PortName := ParamStr(1);

  res := ft.OpenInterface(PortName);  // --- ,Self : Interface Panel
  if res = ftiFehler then
    begin
    MessageDlg('Interfaceproblem mit : ' + PortName, mtWarning, [mbOK], 0);
    cmdStart.SetFocus;
    exit
    end;
  frmRahmen.Caption := 'Klasse FishFace v' + ft.Version + ' : TestRahmen';
  pnlTests.Enabled := true;
  cmdStart.Caption   := 'HALT';
  cmdEnde.Caption    := 'ENDE';
  ft.NotHalt         := false;
  lstLog.Clear;
  printLog('Gestartet ', ft.PortName);
  printLog('NotHalt', ft.NotHalt);
  printLog('Reset', ft.Reset);
  printLog('StatusAnalog', ft.StatusAnalog[0]);
  printLog('InputStatus', ft.StatusInputs, 4);
  printLog('StatusOutputs', ft.StatusOutputs, 4);
  printLog('InterruptEnabled', ft.InterruptEnabled);
  printLog('PanelEnabled', ft.PanelEnabled);
  printLog('LPTAnalog', ft.LPTAnalog);
  printLog('LPTIOADR', ft.LPTIOADR);
  printLog('LPTDelay', ft.LPTDelay);
  end
else begin
  ft.NotHalt := true;
  ft.ClearMotors;
  pnlTests.Enabled := true;
  end;
end;

// --- Test-Routinen ---------------------------------------------------

procedure TfrmRahmen.cmdActionClick(Sender: TObject);
// --- SetMotor(s), ClearMotors, WaitForTime --------
//     GetInput, GetAnalog
// Modell : Lampen an M2, M3, M4. Taster E1, EX, EY -
begin
   lstLog.Clear;
   ft.NotHalt := false;
   pnlTests.Enabled := false;
   printLog('SetMotor Gestartet');
   ft.ClearMotors;
   printLog('ClearMotors');
   printLog('GetInputs', ft.GetInputs, 4);
   ft.SetMotor(4, ftiEin);
   printLog('SetMotor(4, ftiEin)');
   ft.WaitForTime(1000);
   printLog('WaitForTime(1000)');
   ft.SetMotorList(0,0,1,1);
   printLog('SetMotorList(0,0,1,1)');
   ft.WaitForTime(1000);
   ft.SetMotors($4+$10+$40);
   printLog('SetMotors($4+$10+$40)');
   ft.WaitForTime(1000);
   ft.ClearMotors;
   printLog('GetAnalog(0)', ft.GetAnalog(0));
   printLog('GetAnalog(1)', ft.GetAnalog(1));
   printLog('Zum Beenden des Tests : E1 drcken');
   repeat
     if ft.NotHalt then break;
   until ft.GetInput(1);
   printLog('SetMotor ENDE');
   pnlTests.Enabled := true;
end;

procedure TfrmRahmen.cmdLampenClick(Sender: TObject);
// --- Test SetLamp(LPT), EmergencyStop, ResetMotors --
//     Lampen an M1 v/h, M2 v, Taster E1, E2 ----------
begin
   lstLog.Clear;
   ft.NotHalt := false;
   pnlTests.Enabled := false;
   printLog('SetLamp(LPT) Gestartet');
   repeat
     printLog('Start neue LampenSchleife');
     ft.ClearMotors;
     ft.SetLamp(1, ftiEin);
     printLog('SetLamp(1, ftiEin)');
     ft.WaitForTime(1000);
     ft.SetLamp(2, ftiEin);
     ft.WaitForTime(1000);
     ft.SetLamp(3, ftiEin);
     ft.WaitForTime(1000);
     printLog('Lampen 1-3 ein, EmergencyStop(1)');
     ft.EmergencyStop(1);
     printLog('weiter mit altem StatusMotors');
     ft.WaitForTime(1000);
     printLog('Abbruch : ResetMotors(2)');
   until ft.ResetMotors(2);
   printLog('SetLamp ENDE');
   pnlTests.Enabled := true;
end;

procedure TfrmRahmen.cmdMoveToClick(Sender: TObject);
// --- Test MoveTo/MoveDelta und OnPositionChange ---
// Modell : Motor M1 und Impuls E2, Ende E1 ---------
begin
  lstLog.Clear;
  ft.NotHalt := false;
  pnlTests.Enabled := false;
  ft.ClearMotors;
  printLog('MoveTo-Test gestartet');
  ft.MotCntl.Ende[1] := 1;             // --- Endtaster
  ft.MotCntl.EndPosition[1] := 200;    // --- max. Weg von Endposition
  ft.MotCntl.Impuls[1] := 2;           // --- ImpulsTaster
  ft.MotCntl.Name[1] := 'TestMotor';   // --- MotorName
  ft.MotCntl.Nr[1] := 1;               // --- MotorNummer
  printLog('Endstellung : E1 drcken');
  ft.MoveHome;
  printLog('auf Endstellung');
  Mot1Pos := -1;                       // --- Zhlung Positionswechsel
  ft.OnPositionChange:= OnPositionChange;
  ft.MoveTo(16);
  printLog('MoveTo(16)');
  ft.MoveDelta(-12);
  printLog('MoveDelta(-12)');
  ft.OnPositionChange := nil;
  printLog('MoveTo-Test beendet');
  pnlTests.Enabled := true;
end;

procedure TfrmRahmen.cmdPanelClick(Sender: TObject);
// --- Anzeige ft.InterfacePanel -------------------
begin
  ft.ShowPanel(Left+3, Top+33);
end;

procedure TfrmRahmen.cmdWaitForClick(Sender: TObject);
// --- Test der Methoden WaitFor ... -----------------
// Modell : Motor M1, Impuls E2, Ende E1, Taster E8 --
begin
  lstLog.Clear;
  ft.NotHalt := false;
  pnlTests.Enabled := false;
  ft.ClearMotors;
  printLog('WaitFor-Test gestartet');
  ft.OnInputImpuls     := OnInputImpuls;
  ft.OnInterfaceStatus := OnInterfaceStatus;
  ft.SetMotor(1, ftiLinks);
  ft.WaitForChange(2,3,8);
  ft.OnInputImpuls     := nil;
  ft.OnInterfaceStatus := nil;
  printLog('WaitForChange(2,3,2) mit OnInputImpuls/Interface');
  printLog('WaitForChange, Ende : E8');
  ft.WaitForChange(2,999,8);
  ft.SetMotor(1, ftiAus);
  printLog('WaitForChange(2,999,8) ohne InputImpuls');
  printLog('WaitForInput, Ende : E8');
  ft.WaitForInput(8);
  printLog('WaitForLow, E1 : drcken und loslassen');
  ft.WaitForLow(1);
  printLog('WaitFor-Test beendet');
  pnlTests.Enabled := true;
end;

// --- ft.Ereignis-Routinen ---------------------------------------

procedure TfrmRahmen.OnPositionChange(Sender: TFishFace);
var res: Integer;
begin
  res := ft.MotCntl.Position[1];
  if res <> Mot1Pos then begin
    printLog('Position', res);
    Mot1Pos := res;
    end;
end;

procedure TfrmRahmen.OnInputImpuls(Sender: TFishFace;
                                   InputNr, ImpulsNr: Integer);
begin
  printLog('ImpulsNr', ImpulsNr);
end;

procedure TfrmRahmen.OnInterfaceStatus(Sender: TFishFace; Status: Integer);
begin
  printLog('StatusInputs', Status,4);
end;

end.
