// ----------------------------------------------------------------------------
//
// frmRahmen(umFishVT.PAS/DFM)                            Ulrich Mller 24.1.00
//                                                        Procida 400NT Delphi4
// Testrahmen fr die Unit umFishEx.DCU
// START    : ftiOpenInterface, Anzeige Eigenschaften und Freigabe pnlTests
// InterfacePanel : Anzeige des internen Panels
// SetMotor : Test der Methoden SetMotor ... und anderer einfacher,
// SetLamp  : Test der Methoden SetLamp
// WaitFor  : Test der WaitFor... Methoden  und Ereignisse.
//
// Ergebnisse und Dialogfhrung in lstLog (printLog)
//
// Aufbau :
// M1 Motor mit Taster E2 (Sclieer, Kontakte 1 & 3) und Impulsrad
// M1 - M4 : Lampen
// EX : Photowiderstand
// EY : Festwiderstand 100 Ohm
// E1 und E8 Taster (Schlieer)
//
// Der Attribut overload ist Delphi4-spezifisch, in Delphi2/3 streichen und die
// Namen der zugehrenden proceduren um die Ziffern 1-5 erweitern
//
// ----------------------------------------------------------------------------

unit umFishVT;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, umFishEx, ExtCtrls;

type
  TfrmVTMain = class(TForm)
    cmdStart: TButton;
    cmdEnde: TButton;
    lstLog: TListBox;
    pnlTests: TPanel;
    cmdWaitFor: TButton;
    cmdAction: TButton;
    cmdPanel: TButton;
    cmdLampen: TButton;
    procedure cmdEndeClick(Sender: TObject);
    procedure cmdStartClick(Sender: TObject);
    procedure cmdPanelClick(Sender: TObject);
    procedure cmdActionClick(Sender: TObject);
    procedure cmdLampenClick(Sender: TObject);
    procedure cmdWaitForClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    procedure printLog(Text: string); overload;
    procedure printLog(Funktion, StringWert: string); overload;
    procedure printLog(Funktion: string; IntegerWert: Integer); overload;
    procedure printLog(Funktion: string; BoolWert: Boolean); overload;
    procedure printLog(Funktion: string; HexWert, Lae: Cardinal); overload;
  public
    { Public-Deklarationen}
  end;

var
  frmVTMain: TfrmVTMain;

implementation

{$R *.DFM}

uses FishPumD;

var
  PortName: string = 'COM1';

// --- Log-Routinen (overload) ----------------------------------

procedure TfrmVTMain.printLog(Text: string);
begin
  lstLog.Items.Add(Text);
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmVTMain.printLog(Funktion, StringWert: string);
begin
  lstLog.Items.Add(Funktion + ' : ' + StringWert);
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmVTMain.printLog(Funktion: string; IntegerWert: Integer);
begin
  lstLog.Items.Add(Funktion + ' : ' + IntToStr(IntegerWert));
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmVTMain.printLog(Funktion: string; BoolWert: Boolean);
begin
  if BoolWert then lstLog.Items.Add(Funktion + ' : ' + 'true')
  else lstLog.Items.Add(Funktion + ' : ' + 'false');
  lstLog.ItemIndex := lstLog.Items.Count - 1;
end;

procedure TfrmVTMain.printLog(Funktion: string; HexWert, Lae: Cardinal);
begin lstLog.Items.Add(Funktion + ' : ' + IntToHex(HexWert, Lae) + 'h'); end;

// ----------------- Form-Routinen ---------------------------------------

procedure TfrmVTMain.FormCreate(Sender: TObject);
begin
  ftiDCB.LPTDelay   := 5;
  ftiDCB.LPTAnalog := 10;
end;

procedure TfrmVTMain.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  ftiNotHalt := true;
  ftiClearMotors;
  ftiCloseInterface;
end;

procedure TfrmVTMain.cmdEndeClick(Sender: TObject);
// --- Beenden ------------------------------------------------------------
begin
  Self.Close;
end;

procedure TfrmVTMain.cmdStartClick(Sender: TObject);
// --- OpenInterface -------------------------------
//     Anzeige der aktuellen Eigenschaften ---------
var
  res: LongWord;
begin
if cmdStart.Caption = 'START' then begin
  if ParamCount = 0 then
    PortName := InputBox('umFishTest',
      'Bitte Portnamen eingeben : COM1-4 oder LPT1-3 (NT : LPT)', PortName)
  else PortName := ParamStr(1);

  res := ftiOpenInterface(PortName);
  if res = ftiFehler then
    begin
    MessageDlg('Interfaceproblem mit : ' + PortName, mtWarning, [mbOK], 0);
    cmdStart.SetFocus;
    exit
    end;
  frmVTMain.Caption := 'umFishEx.DCU v1.2';
  pnlTests.Enabled := true;
  cmdStart.Caption   := 'HALT';
  cmdEnde.Caption    := 'ENDE';
  ftiNotHalt         := false;
  lstLog.Clear;
  printLog('Gestartet ', PortName);
  printLog('NotHalt', ftiNotHalt);
  printLog('InputStatus', ftiDCB.InputStatus, 4);
  printLog('StatusOutputs', ftiDCB.MotorStatus, 4);
  printLog('LPTAnalog', ftiDCB.LPTAnalog);
  printLog('LPTIOADR', ftiDCB.PortID);
  printLog('LPTDelay', ftiDCB.LPTDelay);
  end
else begin
  ftiNotHalt := true;
  ftiClearMotors;
  pnlTests.Enabled := true;
  end;
end;

// --- Test-Routinen ---------------------------------------------------

procedure TfrmVTMain.cmdActionClick(Sender: TObject);
// --- ftiSetMotor(s), ftiClearMotors, ftiWaitForTime --------
//     ftiGetInput, ftiGetAnalog
// Modell : Lampen an M2, M3, M4. Taster E1, EX, EY -
begin
   lstLog.Clear;
   ftiNotHalt := false;
   pnlTests.Enabled := false;
   printLog('ftiSetMotor Gestartet');
   ftiClearMotors;
   printLog('ftiClearMotors');
   printLog('ftiGetInputs', ftiGetInputs, 4);
   ftiSetMotor(4, ftiEin);
   printLog('ftiSetMotor(4, ftiEin)');
   ftiWaitForTime(1000);
   printLog('ftiWaitForTime(1000)');
   ftiSetMotors($4+$10+$40);
   printLog('ftiSetMotors($4+$10+$40)');
   ftiWaitForTime(1000);
   ftiClearMotors;
   printLog('ftiGetAnalog(0)', ftiGetAnalog(0));
   printLog('ftiGetAnalog(1)', ftiGetAnalog(1));
   printLog('Zum Beenden des Tests : E1 drcken');
   repeat
     if ftiNotHalt then break;
   until ftiGetInput(1);
   printLog('SetMotor ENDE');
   pnlTests.Enabled := true;
end;

procedure TfrmVTMain.cmdLampenClick(Sender: TObject);
// --- Test ftiSetLamp(LPT), ftiFinish --
//     Lampen an M1 v/h, M2 v, Taster E1, E2 ----------
begin
   lstLog.Clear;
   ftiNotHalt := false;
   pnlTests.Enabled := false;
   printLog('SetLamp(LPT) Gestartet');
   repeat
     printLog('Start neue LampenSchleife');
     ftiClearMotors;
     ftiSetLamp(1, ftiEin);
     printLog('ftiSetLamp(1, ftiEin)');
     ftiWaitForTime(1000);
     ftiSetLamp(2, ftiEin);
     ftiWaitForTime(1000);
     ftiSetLamp(3, ftiEin);
     ftiWaitForTime(1000);
     printLog('Abbruch : ftiFinish(8)');
   until ftiFinish(8);
   printLog('SetLamp ENDE');
   pnlTests.Enabled := true;
end;

procedure TfrmVTMain.cmdPanelClick(Sender: TObject);
// --- Anzeige ft.InterfacePanel -------------------
begin
  frmFishPanel.ShowPanel(ftiDCB, PortName);
end;

procedure TfrmVTMain.cmdWaitForClick(Sender: TObject);
// --- Test der Methoden ftiWaitFor ... -----------------
// Modell : Motor M1, Impuls E2, Ende E1, Taster E8 --
begin
  lstLog.Clear;
  ftiNotHalt := false;
  pnlTests.Enabled := false;
  ftiClearMotors;
  printLog('WaitFor-Test gestartet');
  ftiSetMotor(1, ftiLinks);
  ftiWaitForChange(2,3,8);
  printLog('ftiWaitForChange(2,3,2)');
  printLog('ftiWaitForChange, Ende : E8');
  ftiWaitForChange(2,999,8);
  ftiSetMotor(1, ftiAus);
  printLog('ftiWaitForChange(2,999,8)');
  printLog('ftiWaitForInput, Ende : E8');
  ftiWaitForInput(8, true);
  printLog('ftiWaitForLow, E1 : drcken und loslassen');
  ftiWaitForLow(1);
  printLog('WaitFor-Test beendet');
  pnlTests.Enabled := true;
end;

end.
